
class SiteConfigSettings(object):

    @property
    def INSTALLED_APPS(self):
        return super().INSTALLED_APPS + [
            'site_config'
        ]

    @property
    def CONTEXT_PROCESSORS(self):
        return super().CONTEXT_PROCESSORS + [
            'site_config.context_processors.config'
        ]

default = SiteConfigSettings




from django.template import Library
from django.utils.safestring import mark_safe


register = Library()


@register.simple_tag(takes_context=True)
def get_meta_tag(context, field_name, default=''):
    page_meta = context.request.page_meta
    return page_meta.render(field_name, context, default)


@register.inclusion_tag('language_meta_tags.html', takes_context=True)
def get_language_meta_tags(context):
    return context


@register.simple_tag
def get_viewport_tag(content=None):

    if content is None:
        content = 'width=device-width,initial-scale=1'

    return mark_safe('<meta name="viewport" content="{}" />'.format(content))


@register.simple_tag(takes_context=True)
def get_favicon_tag(context, path=None):

    if path is None:
        path = context['STATIC_URL'] + 'img/favicon.ico'

    return mark_safe('<link rel="shortcut icon" href="{}">'.format(path))


@register.inclusion_tag('sitemetrics_tag.html', takes_context=True)
def sitemetrics(context):
    return context



# Generated by Django 2.2.9 on 2020-01-14 17:29

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='HistoryGroup',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, verbose_name='Name')),
                ('code', models.CharField(max_length=100, unique=True, verbose_name='Code')),
            ],
            options={
                'verbose_name': 'History group',
                'verbose_name_plural': 'History groups',
            },
        ),
        migrations.CreateModel(
            name='HistoryRecord',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('text', models.TextField(max_length=1000, verbose_name='Text')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Creation date')),
                ('group', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='history.HistoryGroup', verbose_name='Group')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='history_records', to=settings.AUTH_USER_MODEL, verbose_name='User')),
            ],
            options={
                'verbose_name': 'History record',
                'verbose_name_plural': 'History records',
            },
        ),
    ]




from django.apps import apps, AppConfig
from django.utils.translation import ugettext_lazy as _


default_app_config = 'site_config.SiteConfigApp'


class SiteConfigApp(AppConfig):
    name = 'site_config'
    verbose_name = _("Settings")


class SiteConfig(object):

    def __getattr__(self, name):

        if name.startswith('_'):
            return super(SiteConfig, self).__getattribute__(name)

        if not hasattr(self, '_cached_fields'):
            self._cached_fields = self.get_fields()

        if name in self._cached_fields:
            return self._cached_fields[name].value

        return None

    def get_fields(self):
        fields = apps.get_model('site_config', 'ConfigField').objects.all()
        return {f.name: f for f in fields}

    def reload(self):
        if hasattr(self, '_cached_fields'):
            del self._cached_fields


config = SiteConfig()




from django.urls import path
from django.contrib import admin
from django.utils.module_loading import autodiscover_modules
from adminplus.sites import AdminSitePlus


class AdminSite(AdminSitePlus):

    def get_urls(self):
        urls = super().get_urls()

        for path_str, view, name, urlname, visible in self.custom_views:
            urls = [
                path(path_str, self.admin_view(view), name=urlname),
            ] + urls
        return urls


def register_admin(site_header='Admin'):
    site = AdminSite()
    admin.site = site
    admin.sites.site = site
    admin.site.site_header = site_header
    autodiscover_modules('admin', register_to=site)




from django.contrib import admin
from django.core.exceptions import PermissionDenied
from django.utils.translation import ugettext_lazy as _
from django.utils.safestring import mark_safe

from cap.decorators import short_description

from history.models import HistoryRecord, HistoryGroup


@admin.register(HistoryGroup)
class HistoryGroupAdmin(admin.ModelAdmin):

    list_display = ['name', 'code']

    fields = ['name']

    def has_delete_permission(self, request, obj=None):
        return False


@admin.register(HistoryRecord)
class HistoryRecordAdmin(admin.ModelAdmin):

    list_display = [
        'user', 'text_tag', 'group', 'created'
    ]

    list_display_links = None

    list_pre_page = 100

    list_filter = ['created', 'group', 'user']

    search_fields = ['text']

    @short_description(_('Text'))
    def text_tag(self, obj):
        return mark_safe(obj.text)

    def has_add_permission(self, request):
        return False

    def has_delete_permission(self, request, obj=None):
        return False

    def change_view(self, request, object_id, form_url='', extra_context=None):
        raise PermissionDenied()


class LogHistoryAdmin(admin.ModelAdmin):

    history_group = None

    def save_model(self, request, obj, form, change):
        super().save_model(request, obj, form, change)

        if not change:
            return

        HistoryRecord.log_action(
            action=HistoryRecord.ACTION_CHANGE,
            group=self.history_group,
            user=request.user,
            obj=obj,
            fields=form.changed_data)

    def log_addition(self, request, object, message):
        HistoryRecord.log_action(
            action=HistoryRecord.ACTION_CREATE,
            group=self.history_group,
            user=request.user,
            obj=object)

    def log_deletion(self, request, object, object_repr):
        HistoryRecord.log_action(
            action=HistoryRecord.ACTION_DELETE,
            group=self.history_group,
            user=request.user,
            obj=object)




class CallbackSettings(object):

    @property
    def JAVASCRIPT(self):
        return super().JAVASCRIPT + (
            'callback/modal.js',
        )

    @property
    def INSTALLED_APPS(self):
        apps = super().INSTALLED_APPS + [
            'callback'
        ]

        if not 'captcha' in apps:
            apps += ['captcha']

        return apps


default = CallbackSettings



# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2017-06-12 12:08
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='SearchQuery',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('url', models.URLField(max_length=255, verbose_name='URL')),
                ('text', models.CharField(max_length=255, unique=True, verbose_name='Text')),
                ('result_count', models.IntegerField(verbose_name='Result count')),
            ],
            options={
                'verbose_name': 'Search query',
                'verbose_name_plural': 'Search queries',
            },
        ),
        migrations.CreateModel(
            name='SearchTag',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('text', models.CharField(max_length=255, unique=True, verbose_name='Text')),
            ],
            options={
                'verbose_name': 'Search tag',
                'verbose_name_plural': 'Search tags',
            },
        ),
        migrations.CreateModel(
            name='SearchTagGroup',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, unique=True, verbose_name='Group name')),
            ],
            options={
                'verbose_name': 'Search tag group',
                'verbose_name_plural': 'Search tag groups',
            },
        ),
        migrations.AddField(
            model_name='searchtag',
            name='group',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='model_search.SearchTagGroup', verbose_name='Group'),
        ),
    ]




from django import template
from django.http import HttpRequest

from cap.menu import MenuManager

register = template.Library()


@register.simple_tag(takes_context=True)
def get_menu(context, request):

    if not isinstance(request, HttpRequest):
        return None

    available_apps = context.get('available_apps')

    return MenuManager(available_apps, context, request)




from django import template


register = template.Library()


@register.inclusion_tag(
    'notify-js.html',
    takes_context=True,
    name='notify_js')
def render_notify_js(context):
    return context




BOWER_APPS_MAP = {
    'jquery': [
        'jquery#3.5.1',
        'jquery-form#4.3.0'
    ],
    'bootstrap': 'bootstrap#3.3.7',
    'jasny': 'jasny-bootstrap#3.1.3',
    'fa': 'components-font-awesome#5.15.1',
    'fancybox2': 'fancybox#2.1.6',
    'fancybox': 'fancybox#3.5.7',
    'pgwslideshow': 'pgwslideshow#2.0.2',
    'owl': 'owl.carousel#2.3.4',
    'autocomplete': 'devbridge-autocomplete#1.4.11',
    'tagsinput': 'bootstrap-tagsinput#0.8.0',
    'qtip2': 'qtip2#2.2.1',
    'cookie': 'jquery.cookie#1.4.1',
    'chosen': 'chosen#1.8.7',
    'jquery-ui': 'jquery-ui#1.12.1',
    'treeview': 'bootstrap-treeview#1.2.0',
    'slick': 'slick-carousel#1.8.1'
}


APPS_CSS_MAP = {
    'bootstrap': 'bower_components/bootstrap/dist/css/bootstrap.css',
    'bootstrap-theme': (
        'bower_components/bootstrap/dist/css/bootstrap-theme.css'),
    'jasny': 'bower_components/jasny-bootstrap/dist/css/jasny-bootstrap.css',
    'fa': 'bower_components/components-font-awesome/css/all.css',
    'fancybox2': 'bower_components/fancybox/source/jquery.fancybox.css',
    'fancybox': 'bower_components/fancybox/dist/jquery.fancybox.css',
    'pgwslideshow': [
        'bower_components/pgwslideshow/pgwslideshow.css',
        'bower_components/pgwslideshow/pgwslideshow_light.css'
    ],
    'owl': 'bower_components/owl.carousel/dist/assets/owl.carousel.css',
    'basement': 'css/indents.css',
    'tagsinput': (
        'bower_components/bootstrap-tagsinput/dist/bootstrap-tagsinput.css'),
    'qtip2': 'bower_components/qtip2/basic/jquery.qtip.css',
    'chosen': 'bower_components/chosen/chosen.css',
    'treeview': (
        'bower_components/bootstrap-treeview/dist/bootstrap-treeview.min.css'),
    'jquery-ui': 'bower_components/jquery-ui/themes/ui-lightness/jquery-ui.css',
    'slick': [
        'bower_components/slick-carousel/slick/slick.css',
        'bower_components/slick-carousel/slick/slick-theme.css'
    ]
}


APPS_JS_MAP = {
    'jquery': [
        'bower_components/jquery/dist/jquery.js',
        'bower_components/jquery-form/dist/jquery.form.min.js',
        'jquery/jquery.ba-bbq.js',
        'jquery/ajax-csrf.js',
        'modal.js'
    ],
    'bootstrap': 'bower_components/bootstrap/dist/js/bootstrap.js',
    'jasny': 'bower_components/jasny-bootstrap/dist/js/jasny-bootstrap.js',
    'fancybox2': 'bower_components/fancybox/source/jquery.fancybox.js',
    'fancybox': 'bower_components/fancybox/dist/jquery.fancybox.js',
    'pgwslideshow': 'bower_components/pgwslideshow/pgwslideshow.js',
    'owl': 'bower_components/owl.carousel/dist/owl.carousel.js',
    'autocomplete': (
        'bower_components/devbridge-autocomplete/dist/jquery.autocomplete.js'),
    'tagsinput': (
        'bower_components/bootstrap-tagsinput/dist/bootstrap-tagsinput.js'),
    'qtip2': 'bower_components/qtip2/basic/jquery.qtip.js',
    'cookie': 'bower_components/jquery.cookie/jquery.cookie.js',
    'treeview': (
        'bower_components/bootstrap-treeview/dist/bootstrap-treeview.min.js'),
    'jquery-ui': 'bower_components/jquery-ui/jquery-ui.js',
    'slick': 'bower_components/slick-carousel/slick/slick.js'
}




from django import forms

from captcha.fields import ReCaptchaField

from reviews.models import Review


class ReviewForm(forms.ModelForm):

    captcha = ReCaptchaField()

    class Meta:
        model = Review
        fields = ['name', 'text', 'rating', 'photo']




class SliderSettings(object):
    @property
    def INSTALLED_APPS(self):
        return super().INSTALLED_APPS + [
            'slider'
        ]

    @property
    def STYLESHEETS(self):
        return super().STYLESHEETS + (
            'slider/slideshow.css',
        )

    @property
    def STATIC_APPS(self):
        apps = super().STATIC_APPS

        if 'slick' not in apps:
            apps.append('slick')

        if 'fancybox' not in apps:
            apps.append('fancybox')

        return apps


default = SliderSettings




from django import forms

from captcha.fields import ReCaptchaField

from callback.models import Callback
from callback.widgets import TimeSelect


class CallbackForm(forms.ModelForm):

    captcha = ReCaptchaField()

    class Meta:

        model = Callback

        fields = [
            'answer_time', 'answer_start_time', 'answer_end_time', 'comment',
            'mobile'
        ]

        widgets = {
            'answer_time': forms.RadioSelect,
            'answer_start_time': TimeSelect,
            'answer_end_time': TimeSelect
        }




from seo.lib import get_page_meta


class PageMetaMiddleware(object):

    def __init__(self, get_response):
        self.get_response = get_response

    def __call__(self, request):
        
        request.page_meta = get_page_meta(request)

        return self.get_response(request)




from django.apps import AppConfig
from django.contrib.admin.options import ModelAdmin

ALL_FIELDS = '__all__'

CAP_FORM_SIZE_LABEL = 'col-xs-12 col-sm-3 col-md-2'
CAP_FORM_SIZE_INLINE = (CAP_FORM_SIZE_LABEL, 'col-xs-12 col-sm-9 col-md-10 form-inline')
CAP_FORM_SIZE_SMALL = (CAP_FORM_SIZE_LABEL, 'col-xs-12 col-sm-6 col-md-5 col-lg-4')
CAP_FORM_SIZE_HALF = (CAP_FORM_SIZE_LABEL, 'col-xs-12 col-sm-7 col-md-6 col-lg-5')
CAP_FORM_SIZE_LARGE = (CAP_FORM_SIZE_LABEL, 'col-xs-12 col-sm-8 col-md-7 col-lg-6')
CAP_FORM_SIZE_X_LARGE = (CAP_FORM_SIZE_LABEL, 'col-xs-12 col-sm-9 col-md-8 col-lg-7')
CAP_FORM_SIZE_XX_LARGE = (CAP_FORM_SIZE_LABEL, 'col-xs-12 col-sm-9 col-md-10 col-lg-8')
CAP_FORM_SIZE_XXX_LARGE = (CAP_FORM_SIZE_LABEL, 'col-xs-12 col-sm-9 col-md-10 col-lg-9')
CAP_FORM_SIZE_FULL = (CAP_FORM_SIZE_LABEL, 'col-xs-12 col-sm-9 col-md-10')


class DjangoCapConfig(AppConfig):

    name = 'cap'
    verbose_name = 'Django Cap'

    layout = 'vertical'

    toggle_changelist_top_actions = True

    menu = []

    form_submit_on_right = False

    form_size = {
        'default': CAP_FORM_SIZE_X_LARGE,
        'widgets': {
            'RelatedFieldWidgetWrapper': CAP_FORM_SIZE_XXX_LARGE
        }
    }

    def __init__(self, app_name, app_module):

        ModelAdmin.actions_on_top = True
        ModelAdmin.actions_on_bottom = True

        super().__init__(app_name, app_module)




from django.shortcuts import render
from django.http.response import HttpResponse
from django.views.generic import View, ListView
from django.utils.translation import ugettext_lazy as _
from django.core.mail import mail_managers
from django.template.loader import render_to_string
from django.contrib.sites.models import Site

from pagination import PaginationMixin

from reviews.models import Review
from reviews.forms import ReviewForm


class ReviewListView(PaginationMixin, ListView):

    queryset = Review.objects.filter(is_active=True)
    paginate_by = 10
    template_name = 'reviews/list.html'


class ReviewAPI(View):

    def get(self, request, *args, **kwargs):
        context = {'form': ReviewForm()}
        return render(request, 'reviews/new_review_modal.html', context)

    def post(self, request, *args, **kwargs):

        form = ReviewForm(data=request.POST, files=request.FILES)

        if form.is_valid():

            review = form.save(commit=False)

            if request.user.is_authenticated:
                review.user = request.user

            review.save()

            self._send_new_review_email(review)

            return HttpResponse(_('Review was successfully sent'))

        context = {'form': form}

        return render(
            request, 'reviews/new_review_form.html', context, status=400)

    def _send_new_review_email(self, review):

        subject = '{} #{}'.format(_('New review'), review.id)

        context = {'object': review, 'site': Site.objects.get_current()}

        html = render_to_string('reviews/new_review_email.html', context)

        mail_managers(
            subject=subject, message='', html_message=html, fail_silently=True
        )




class ReviewSettings(object):

    @property
    def STYLESHEETS(self):
        return super().STYLESHEETS + (
            'jquery.rateit/rateit.css',
        )

    @property
    def JAVASCRIPT(self):
        return super().JAVASCRIPT + (
            'reviews/reviews.js',
            'jquery.rateit/jquery.rateit.js',
            'jquery.form.js',
        )

    @property
    def INSTALLED_APPS(self):
        apps = super().INSTALLED_APPS + [
            'reviews'
        ]

        if not 'captcha' in apps:
            apps += ['captcha']

        return apps


default = ReviewSettings




from django.apps import apps
from django.conf import settings
from datetime import datetime
from django.urls import reverse
from django.utils.translation import activate
from django.contrib.sitemaps import Sitemap as DjangoSitemap


class Sitemap(DjangoSitemap):

    changefreq = 'monthly'
    priority = 1.0
    patterns = []

    def items(self):

        urls = []

        for lang_code, lang_name in settings.LANGUAGES:

            activate(lang_code)

            urls += list(self.get_extra_urls())

            if apps.is_installed('flatpages'):
                from flatpages.models import FlatPage
                for fp in FlatPage.objects.all():
                    urls.append(
                        reverse('flatpages:page', kwargs={'url': fp.url}))

            for pattern in self.patterns:
                urls.append(reverse(pattern))

            try:
                urls.append(reverse('sitemap-tree'))
            except Exception:
                pass

        return urls

    def get_extra_urls(self):
        return []

    def location(self, obj):
        return obj

    def lastmod(self, obj):
        return datetime.now()




from django.apps import AppConfig
from django.utils.translation import ugettext_lazy as _


class ReviewsConfig(AppConfig):
    name = 'reviews'
    verbose_name = _("Reviews")


default_app_config = 'reviews.ReviewsConfig'




from django.apps import AppConfig
from django.utils.translation import ugettext_lazy as _


from model_search.lib import (
    normalize_query, model_search, tags_search, build_query)


__all__ = ['normalize_query', 'build_query', 'model_search']


class ModelSearchConfig(AppConfig):
    name = 'model_search'
    verbose_name = _("Search")


default_app_config = 'model_search.ModelSearchConfig'



# Generated by Django 3.0.10 on 2020-11-19 05:00

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('seo', '0007_search_query'),
    ]

    operations = [
        migrations.AddField(
            model_name='pagemeta',
            name='breadcrumb_en',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Breadcrumb'),
        ),
        migrations.AddField(
            model_name='pagemeta',
            name='breadcrumb_ru',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Breadcrumb'),
        ),
        migrations.AddField(
            model_name='pagemeta',
            name='breadcrumb_uk',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Breadcrumb'),
        ),
        migrations.AddField(
            model_name='pagemeta',
            name='description_en',
            field=models.CharField(blank=True, max_length=155, null=True, verbose_name='Description'),
        ),
        migrations.AddField(
            model_name='pagemeta',
            name='description_ru',
            field=models.CharField(blank=True, max_length=155, null=True, verbose_name='Description'),
        ),
        migrations.AddField(
            model_name='pagemeta',
            name='description_uk',
            field=models.CharField(blank=True, max_length=155, null=True, verbose_name='Description'),
        ),
        migrations.AddField(
            model_name='pagemeta',
            name='header_en',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Header'),
        ),
        migrations.AddField(
            model_name='pagemeta',
            name='header_ru',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Header'),
        ),
        migrations.AddField(
            model_name='pagemeta',
            name='header_uk',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Header'),
        ),
        migrations.AddField(
            model_name='pagemeta',
            name='keywords_en',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Keywords'),
        ),
        migrations.AddField(
            model_name='pagemeta',
            name='keywords_ru',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Keywords'),
        ),
        migrations.AddField(
            model_name='pagemeta',
            name='keywords_uk',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Keywords'),
        ),
        migrations.AddField(
            model_name='pagemeta',
            name='title_en',
            field=models.CharField(max_length=68, null=True, verbose_name='Title'),
        ),
        migrations.AddField(
            model_name='pagemeta',
            name='title_ru',
            field=models.CharField(max_length=68, null=True, verbose_name='Title'),
        ),
        migrations.AddField(
            model_name='pagemeta',
            name='title_uk',
            field=models.CharField(max_length=68, null=True, verbose_name='Title'),
        ),
    ]



from django.apps import AppConfig
from django.utils.translation import ugettext_lazy as _


class FAQConfig(AppConfig):
    name = 'faq'
    verbose_name = _("FAQ")


default_app_config = 'faq.FAQConfig'




from django.db import models
from django.contrib import admin

from callback.models import Callback
from callback.widgets import TimeSelect


@admin.register(Callback)
class CallbackAdmin(admin.ModelAdmin):

    list_display = [
        'id', 'mobile', 'comment', 'get_answer_time_display',
        'answer_start_time', 'answer_end_time', 'date_created', 'user',
    ]

    list_display_links = ['id', 'mobile']

    list_filter = ['answer_time']

    search_fields = ['mobile']

    formfield_overrides = {
        models.TimeField: {'widget': TimeSelect}
    }




from django.apps import apps
from django.contrib import admin

from seo.models import PageMeta, RedirectRecord, ErrorRecord, SearchQuery


def _get_page_meta_parent_admin_classes():

    if apps.is_installed('modeltranslation'):
        from modeltranslation.admin import TranslationAdmin
        classes = [TranslationAdmin]
    else:
        classes = [admin.ModelAdmin]

    if apps.is_installed('import_export'):

        from import_export.resources import ModelResource
        from import_export.admin import ImportExportMixin, ExportActionMixin

        class PageMetaResource(ModelResource):
            class Meta:
                model = PageMeta
                exclude = ('id', )

        class ImportExportAdmin(
                ImportExportMixin,
                ExportActionMixin):

            actions_on_bottom = False
            resource_class = PageMetaResource

        classes.append(ImportExportAdmin)

    return classes


@admin.register(PageMeta)
class PageMetaAdmin(*_get_page_meta_parent_admin_classes()):

    list_display = ['url', 'title', 'robots']
    list_editable = ['robots']
    list_filter = ['robots']
    search_fields = ['url', 'title']


@admin.register(RedirectRecord)
class RedirectRecordAdmin(admin.ModelAdmin):

    list_display = ['id', 'old_path', 'new_path']
    list_display_links = ['old_path', 'new_path']
    search_fields = ['old_path', 'new_path']


@admin.register(ErrorRecord)
class ErrorRecordAdmin(admin.ModelAdmin):

    list_display = [
        'id', 'path', 'method', 'status_code', 'referrer', 'created']
    list_display_links = ['path']
    search_fields = ['path']
    list_filter = ['status_code']


@admin.register(SearchQuery)
class SearchQueryAdmin(admin.ModelAdmin):
    list_display = ['created', 'query', 'filter_options', 'result_count']
    search_fields = ['query', 'filter_options']



# Generated by Django 3.0.10 on 2020-11-19 04:58

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('seo', '0006_pagemeta_og_image'),
    ]

    operations = [
        migrations.CreateModel(
            name='SearchQuery',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('query', models.CharField(blank=True, max_length=255, verbose_name='Query')),
                ('result_count', models.IntegerField(verbose_name='Result count')),
                ('filter_options', models.TextField(blank=True, max_length=2000, verbose_name='Filter')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
            ],
            options={
                'verbose_name': 'Search query',
                'verbose_name_plural': 'Search queries',
            },
        ),
    ]




from django.apps import AppConfig
from django.utils.translation import ugettext_lazy as _


class CallbackAppConfig(AppConfig):

    name = 'callback'
    verbose_name = _('Callback')


default_app_config = 'callback.CallbackAppConfig'




from django.conf import settings
from django.apps import apps
from django.shortcuts import render
from django.http.response import HttpResponse
from django.views.generic import FormView
from django.core.mail import send_mail
from django.template.loader import render_to_string

from callback.forms import CallbackForm


class CreateCallbackView(FormView):

    form_class = CallbackForm
    template_name = 'callback/modal.html'

    def get_initial(self):

        user = self.request.user

        if user.is_authenticated:
            return {'mobile': self.get_user_mobile(user)}

        return self.initial

    def form_valid(self, form):

        obj = form.save(commit=False)

        if self.request.user.is_authenticated:
            obj.user = self.request.user

        obj.save()

        self.send_email_notification(obj)
        self.send_sms_notification(obj)

        message = render_to_string(
            'callback/success_message.html', {'object': obj})

        return HttpResponse(message)

    def form_invalid(self, form):
        return render(
            self.request, 'callback/form.html', {'form': form}, status=403)

    def send_email_notification(self, obj):

        context = self.get_notifications_context(obj)

        subject = render_to_string('callback/email/subject.txt', context)

        html = render_to_string('callback/email/message.html', context)

        send_mail(
            subject=subject.strip(),
            message='',
            from_email=settings.DEFAULT_FROM_EMAIL,
            html_message=html,
            recipient_list=self.get_email_recipients())

    @staticmethod
    def get_user_mobile(user):
        try:
            return user.profile.mobile if hasattr(user, 'profile') else ''
        except Exception:
            pass
        
        return ''

    @staticmethod
    def get_email_recipients():
        return [a[1] for a in settings.MANAGERS]

    def send_sms_notification(self, obj):

        if not apps.is_installed('turbosms'):
            return

        from turbosms.lib import send_sms_from_template

        context = self.get_notifications_context(obj)

        send_sms_from_template('callback/sms.txt', context)

    @staticmethod
    def get_notifications_context(obj):
        return {
            'object': obj,
            'site': apps.get_model('sites', 'Site').objects.get_current()
        }




from django.conf import settings

from turbosms import defaults


IS_SMS_ENABLED = getattr(settings, 'IS_SMS_ENABLED', defaults.IS_SMS_ENABLED)

SMS_RECIPIENTS = getattr(settings, 'SMS_RECIPIENTS', defaults.SMS_RECIPIENTS)

SMS_SIGNATURE = getattr(settings, 'SMS_SIGNATURE', defaults.SMS_SIGNATURE)

SMS_USERNAME = getattr(settings, 'SMS_USERNAME', '')




class FAQSettings(object):

    @property
    def INSTALLED_APPS(self):
        apps = super().INSTALLED_APPS + ['faq']

        if 'ordered_model' not in apps:
            apps.append('ordered_model')

        return apps


default = FAQSettings
